@@ -307,17 +307,13 @@ class IptablesManager(object):
     # Flag to denote iptables supports --random-fully argument
     _random_fully = None
 
-    def __init__(self, _execute=None, state_less=False, use_ipv6=False,
-                 nat=True, namespace=None, binary_name=binary_name):
-        if _execute:
-            self.execute = _execute
-        else:
-            self.execute = linux_utils.execute
-
+    def __init__(self, state_less=False, use_ipv6=False, nat=True,
+                 namespace=None, binary_name=binary_name, external_lock=True):
         self.use_ipv6 = use_ipv6
         self.namespace = namespace
         self.iptables_apply_deferred = False
         self.wrap_name = binary_name[:16]
+        self.external_lock = external_lock
 
         self.ipv4 = {'filter': IptablesTable(binary_name=self.wrap_name)}
         self.ipv6 = {'filter': IptablesTable(binary_name=self.wrap_name)}
@@ -463,7 +459,8 @@ class IptablesManager(object):
         # NOTE(ihrachys) we may get rid of the lock once all supported
         # platforms get iptables with 999eaa241212d3952ddff39a99d0d55a74e3639e
         # ("iptables-restore: support acquiring the lock.")
-        with lockutils.lock(lock_name, runtime.SYNCHRONIZED_PREFIX, True):
+        with lockutils.lock(lock_name, runtime.SYNCHRONIZED_PREFIX,
+                            external=self.external_lock):
             first = self._apply_synchronized()
             if not cfg.CONF.AGENT.debug_iptables_rules:
                 return first
@@ -481,12 +478,14 @@ class IptablesManager(object):
         args = ['iptables-save', '-t', table]
         if self.namespace:
             args = ['ip', 'netns', 'exec', self.namespace] + args
-        return self.execute(args, run_as_root=True).split('\n')
+        return linux_utils.execute(args, run_as_root=True,
+                                   privsep_exec=True).split('\n')
 
     def _get_version(self):
         # Output example is "iptables v1.6.2"
         args = ['iptables', '--version']
-        version = str(self.execute(args, run_as_root=True).split()[1][1:])
+        version = str(linux_utils.execute(
+            args, run_as_root=True, privsep_exec=True).split()[1][1:])
         LOG.debug("IPTables version installed: %s", version)
         return version
 
@@ -498,6 +497,10 @@ class IptablesManager(object):
         version = self._get_version()
         self.__class__._random_fully = utils.is_version_greater_equal(
             version, n_const.IPTABLES_RANDOM_FULLY_VERSION)
+
+        self._random_fully = self._random_fully and \
+            cfg.CONF.AGENT.use_random_fully
+
         return self._random_fully
 
     @property
@@ -511,8 +514,8 @@ class IptablesManager(object):
             args += ['-w', self.xlock_wait_time, '-W', XLOCK_WAIT_INTERVAL]
         try:
             kwargs = {} if lock else {'log_fail_as_error': False}
-            self.execute(args, process_input='\n'.join(commands),
-                         run_as_root=True, **kwargs)
+            linux_utils.execute(args, process_input='\n'.join(commands),
+                                run_as_root=True, privsep_exec=True, **kwargs)
         except RuntimeError as error:
             return error
 
@@ -574,7 +577,8 @@ class IptablesManager(object):
             if self.namespace:
                 args = ['ip', 'netns', 'exec', self.namespace] + args
             try:
-                save_output = self.execute(args, run_as_root=True)
+                save_output = linux_utils.execute(args, run_as_root=True,
+                                                  privsep_exec=True)
             except RuntimeError:
                 # We could be racing with a cron job deleting namespaces.
                 # It is useless to try to apply iptables rules over and
@@ -775,7 +779,16 @@ class IptablesManager(object):
                 args.append('-Z')
             if self.namespace:
                 args = ['ip', 'netns', 'exec', self.namespace] + args
-            current_table = self.execute(args, run_as_root=True)
+
+            # Execute iptables command in the linux host.
+            # When routers migrate from a host,an exception might happen here,
+            # and we do not care about it. Therefore, we do not need to log
+            # this error in production environments. Only when debug mode is
+            # enabled is that we need to log the error. This is used to avoid
+            # generating alarms that will be ignored by  operators.
+            current_table = linux_utils.execute(
+                args, run_as_root=True, privsep_exec=True,
+                log_fail_as_error=cfg.CONF.debug)
             current_lines = current_table.split('\n')
 
             for line in current_lines[2:]:
