@@ -167,7 +167,8 @@ SUPPORTED_DHCP_OPTS_MAPPING = {
         '119': 'domain_search_list',
         '252': 'wpad',
         '210': 'path_prefix',
-        '150': 'tftp_server_address'},
+        '150': 'tftp_server_address',
+        '255': 'next_server'},
     6: {'server-id': 'server_id',
         'dns-server': 'dns_server',
         'domain-search': 'domain_search',
