@@ -38,7 +38,7 @@ LANG=C
 : ${PUBLIC_NETWORK_NAME:=public}
 : ${IMAGE_NAME:=cirros}
 : ${SERVER_USER_NAME:=cirros}
-: ${VALIDATE_MIGRATION:=True}
+: ${VALIDATE_MIGRATION:=False}
 : ${DHCP_RENEWAL_TIME:=30}
 : ${CREATE_BACKUP:=True}
 : ${BACKUP_MIGRATION_IP:=192.168.24.1} # TODO: Document this new var
